@@ -15,6 +15,7 @@ use Icinga\Module\Icingadb\Common\HostStates;
 use Icinga\Module\Icingadb\Common\Links;
 use Icinga\Module\Icingadb\Common\TicketLinks;
 use Icinga\Module\Icingadb\Hook\ExtensionHook\ObjectDetailExtensionHook;
+use Icinga\Module\Icingadb\Widget\ItemList\ObjectList;
 use Icinga\Module\Icingadb\Widget\MarkdownText;
 use Icinga\Module\Icingadb\Common\ServiceLink;
 use Icinga\Module\Icingadb\Common\ServiceStates;
@@ -27,10 +28,10 @@ use Icinga\Module\Icingadb\Model\NotificationHistory;
 use Icinga\Module\Icingadb\Model\StateHistory;
 use Icinga\Module\Icingadb\Util\PluginOutput;
 use Icinga\Module\Icingadb\Widget\ShowMore;
+use ipl\Web\Url;
 use ipl\Web\Widget\CopyToClipboard;
 use ipl\Web\Widget\EmptyState;
 use ipl\Web\Widget\HorizontalKeyValue;
-use Icinga\Module\Icingadb\Widget\ItemTable\UserTable;
 use Icinga\Module\Icingadb\Widget\PluginOutputContainer;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\FormattedString;
@@ -151,14 +152,14 @@ class EventDetail extends BaseHtmlElement
         $eventInfo[] = new HorizontalKeyValue($objectKey, $objectInfo);
 
 
-        $notifiedUsers = [new HtmlElement('h2', null, Text::create(t('Notified Users')))];
+        $notifiedUsers = [new HtmlElement('h2', null, Text::create(t('Notified Contacts')))];
 
         if ($notification->users_notified === 0) {
             $notifiedUsers[] = new EmptyState(t('None', 'notified users: none'));
-        } elseif (! $this->isPermittedRoute('users')) {
+        } elseif (! $this->isPermittedRoute('contacts')) {
             $notifiedUsers[] = Text::create(sprintf(tp(
-                'This notification was sent to a single user',
-                'This notification was sent to %d users',
+                'This notification was sent to a single contact',
+                'This notification was sent to %d contacts',
                 $notification->users_notified
             ), $notification->users_notified));
         } elseif ($notification->users_notified > 0) {
@@ -169,7 +170,7 @@ class EventDetail extends BaseHtmlElement
             $users = $users->execute();
             /** @var ResultSet $users */
 
-            $notifiedUsers[] = new UserTable($users);
+            $notifiedUsers[] = new ObjectList($users);
             $notifiedUsers[] = (new ShowMore(
                 $users,
                 Links::users()->addParams(['notification_history.id' => bin2hex($notification->id)]),
